Crate lnecho

Crate lnecho 

lnecho

These Are the tools used to create an echo like command

Structs

Config
Used to create the config that the run function needs.

Functions

run
Runs the main program